TremendousGift class
Constructors
- TremendousGift({required String apiKey, required TremendousEnv environment})
Properties
- apiKey → String
-
final
- environment → TremendousEnv
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
generateVoucher(
{required String fundingSourceId, required double amount, required String currencyCode, required String method, required String recipientName, required String recipientEmail, String? campaignId, List< String> ? products}) → Future<OrderResponse> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited